WinscardLinux class

Linux bindings for pcsc lib

Constructors

WinscardLinux(DynamicLibrary dynamicLibrary)
The symbols are looked up in dynamicLibrary.
WinscardLinux.fromLookup(Pointer<T> lookup<T extends NativeType>(String symbolName))
The symbols are looked up with lookup.

Properties

g_rgSCardRawPci SCARD_IO_REQUEST
no setter
g_rgSCardT0Pci SCARD_IO_REQUEST
no setter
g_rgSCardT1Pci SCARD_IO_REQUEST
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pcsc_stringify_error(int arg0) Pointer<Char>
SCardBeginTransaction(int hCard) int
SCardCancel(int hContext) int
SCardConnect(int hContext, LPCSTR szReader, int dwShareMode, int dwPreferredProtocols, LPSCARDHANDLE phCard, LPDWORD pdwActiveProtocol) int
SCardControl(int hCard, int dwControlCode, LPCVOID pbSendBuffer, int cbSendLength, LPVOID pbRecvBuffer, int cbRecvLength, LPDWORD lpBytesReturned) int
SCardDisconnect(int hCard, int dwDisposition) int
SCardEndTransaction(int hCard, int dwDisposition) int
SCardEstablishContext(int dwScope, LPCVOID pvReserved1, LPCVOID pvReserved2, LPSCARDCONTEXT phContext) int
SCardFreeMemory(int hContext, LPCVOID pvMem) int
SCardGetAttrib(int hCard, int dwAttrId, LPBYTE pbAttr, LPDWORD pcbAttrLen) int
SCardGetStatusChange(int hContext, int dwTimeout, Pointer<SCARD_READERSTATE> rgReaderStates, int cReaders) int
SCardIsValidContext(int hContext) int
SCardListReaderGroups(int hContext, LPSTR mszGroups, LPDWORD pcchGroups) int
SCardListReaders(int hContext, LPCSTR mszGroups, LPSTR mszReaders, LPDWORD pcchReaders) int
SCardReconnect(int hCard, int dwShareMode, int dwPreferredProtocols, int dwInitialization, LPDWORD pdwActiveProtocol) int
SCardReleaseContext(int hContext) int
SCardSetAttrib(int hCard, int dwAttrId, LPCBYTE pbAttr, int cbAttrLen) int
SCardStatus(int hCard, LPSTR mszReaderName, LPDWORD pcchReaderLen, LPDWORD pdwState, LPDWORD pdwProtocol, LPBYTE pbAtr, LPDWORD pcbAtrLen) int
SCardTransmit(int hCard, Pointer<SCARD_IO_REQUEST> pioSendPci, LPCBYTE pbSendBuffer, int cbSendLength, Pointer<SCARD_IO_REQUEST> pioRecvPci, LPBYTE pbRecvBuffer, LPDWORD pcbRecvLength) int
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited