PcscBindings class abstract
Base class for PC/SC bindings - combines interface and implementation
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolateEntryPoint → void Function(SendPort)
-
Platform-specific isolate entry point
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginTransaction(
int hCard) → Future< SCardResult> -
cancel(
int hContext) → Future< SCardResult> -
connect(
int hContext, String szReader, int dwPreferredProtocols) → Future< PcscResult< SCardHandle> > -
control(
int hCard, int dwControlCode, List< int> pbSendBuffer) → Future<PcscResult< List< >int> > -
createCommandFactory(
) → PcscCommandFactory - Platform-specific command factory
-
disconnect(
int hCard, int dwDisposition) → Future< SCardResult> -
dispose(
) → void -
endTransaction(
int hCard, int dwDisposition) → Future< SCardResult> -
establishContext(
int dwScope) → Future< PcscResult< SCardContext> > -
getAttrib(
int hCard, int dwAttrId) → Future< PcscResult< List< >int> > -
getStatusChange(
int hContext, int dwTimeout, List< SCardReaderState> rgReaderStates) → Future<PcscResult< List< >SCardReaderState> > -
isValidContext(
int hContext) → Future< SCardResult> -
listReaderGroups(
int hContext) → Future< PcscResult< List< >String> > -
listReaders(
int hContext) → Future< PcscResult< List< >String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reconnect(
int hCard, int dwPreferredProtocols, int dwInitialization) → Future< PcscResult< SCardHandle> > -
releaseContext(
int hContext) → Future< SCardResult> -
setAttrib(
int hCard, int dwAttrId, List< int> pbAttr) → Future<SCardResult> -
status(
int hCard) → Future< PcscResult< SCardStatus> > -
toString(
) → String -
A string representation of this object.
inherited
-
transmit(
int hCard, int pioSendPci, List< int> pbSendBuffer) → Future<PcscResult< List< >int> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited